@@ -50,10 +50,10 @@ class SignalBase():
             sortie.nom = nom + "_copié"
         return sortie
 
-    def calculer_vecteur_t(self, liste_imin_imax):
+    def calculer_vecteur_t(self, liste_imin_imax = [None, None]):
         return self.base_de_temps.calculer_vecteur_t(liste_imin_imax)
 
-    def calculer_vecteur_f(self, liste_imin_imax):
+    def calculer_vecteur_f(self, liste_imin_imax = [None, None]):
         return self.base_de_frequence.calculer_vecteur_f(liste_imin_imax)
 
 
