@@ -12,15 +12,15 @@ except:
     # print(" -> Fonctionnement en mode émulation")
     import acquisition.emulateur_sysam_sp5 as pycan
 
-from signaux.signal_gbf import GBF
-from signaux.signal_fourier import Fourier
-from signaux.signal_sysam import Sysam
+from signaux.signal_gbf import SignalGBF
+from signaux.signal_fourier import SignalFourier
+from signaux.signal_sysam import SignalSysam
 
 import base.utiles_base as utb
 
 class Sysam1Base():
     def __init__(self, liste_signaux, affichage):
-        self.sysam = pycan.Sysam("SP5")
+        self.sysam = pycan.SignalSysam("SP5")
         self.affichage = affichage
 
         if isinstance(liste_signaux, list) and len(liste_signaux)> 0:
@@ -92,7 +92,7 @@ if __name__ == "__main__":
     # N = 6
     # liste_signaux = []
     # for i in range(N):
-    #     liste_signaux.append(GBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te))
+    #     liste_signaux.append(SignalGBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te))
 
     # liste_signaux[0].configurer_voie("SA1", repetition = True)
     # liste_signaux[1].configurer_voie("SA2", repetition = True)
@@ -111,5 +111,5 @@ if __name__ == "__main__":
     # sysam = Sysam1Base(liste_signaux)
     # del(sysam)
 
-    sysam = pycan.Sysam("SP5")
+    sysam = pycan.SignalSysam("SP5")
     sysam.fermer()
