@@ -13,9 +13,9 @@ except:
 
 from sysam.sysam_2_mode import Sysam2Mode
 
-from signaux.signal_gbf import GBF
-from signaux.signal_fourier import Fourier
-from signaux.signal_sysam import Sysam
+from signaux.signal_gbf import SignalGBF
+from signaux.signal_fourier import SignalFourier
+from signaux.signal_sysam import SignalSysam
 
 import base.voie_base
 import base.utiles_base as utb
@@ -174,7 +174,7 @@ if __name__ == "__main__":
     N = 10
     liste_signaux = []
     for i in range(N):
-        liste_signaux.append(GBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te))
+        liste_signaux.append(SignalGBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te))
 
     # # Test noms KO
     # liste_signaux[0].configurer_voie("SA1", repetition = True)
@@ -224,8 +224,8 @@ if __name__ == "__main__":
 
     # # tester entrees echantillonnées trop vite
     # Te2 = 1e-7
-    # liste_signaux[2] = GBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te2)
-    # liste_signaux[4] = GBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te2)
+    # liste_signaux[2] = SignalGBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te2)
+    # liste_signaux[4] = SignalGBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te2)
     # liste_signaux[0].configurer_voie("SA1", repetition = True)
     # liste_signaux[1].configurer_voie("SA2", repetition = True)
     # liste_signaux[2].configurer_voie("EA1", repetition = True)
@@ -238,8 +238,8 @@ if __name__ == "__main__":
 
     # # tester sorties echantillonnées trop vite
     # Te2 = 1e-7
-    # liste_signaux[0] = GBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te2)
-    # liste_signaux[1] = GBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te2)
+    # liste_signaux[0] = SignalGBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te2)
+    # liste_signaux[1] = SignalGBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te2)
     # liste_signaux[0].configurer_voie("SA1", repetition = True)
     # liste_signaux[1].configurer_voie("SA2", repetition = True)
     # liste_signaux[2].configurer_voie("EA1", repetition = True)
@@ -252,8 +252,8 @@ if __name__ == "__main__":
 
     # # tester compatibilité bases de temps des entrées
     # Te2 = 1e-5
-    # liste_signaux[2] = GBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te2)
-    # liste_signaux[4] = GBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te2)
+    # liste_signaux[2] = SignalGBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te2)
+    # liste_signaux[4] = SignalGBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te2)
     # liste_signaux[0].configurer_voie("SA1", repetition = True)
     # liste_signaux[1].configurer_voie("SA2", repetition = True)
     # liste_signaux[2].configurer_voie("EA1", repetition = True)
@@ -266,7 +266,7 @@ if __name__ == "__main__":
 
     # # tester compatibilité bases de temps des sorties Te entree = Te sortie si synchrone
     # Te2 = 1e-5
-    # liste_signaux[0] = GBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te2)
+    # liste_signaux[0] = SignalGBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te2)
     # liste_signaux[0].configurer_voie("SA1", repetition = True)
     # liste_signaux[1].configurer_voie("SA2", repetition = True)
     # liste_signaux[2].configurer_voie("EA1", repetition = True)
@@ -278,7 +278,7 @@ if __name__ == "__main__":
 
     # # tester compatibilité bases de temps des sorties sorties tardives
     # liste_tmin_tmax2 = [1e-2, 8e-2]
-    # liste_signaux[0] = GBF(liste_tmin_tmax = liste_tmin_tmax2, Te = Te)
+    # liste_signaux[0] = SignalGBF(liste_tmin_tmax = liste_tmin_tmax2, Te = Te)
     # liste_signaux[0].configurer_voie("SA1", repetition = True)
     # liste_signaux[1].configurer_voie("SA2", repetition = True)
     # liste_signaux[2].configurer_voie("EA1", repetition = True)
@@ -290,7 +290,7 @@ if __name__ == "__main__":
 
     # tester espace mémoire
     liste_tmin_tmax2 = [0, 27]
-    liste_signaux[0] = GBF(liste_tmin_tmax = liste_tmin_tmax2, Te = Te)
+    liste_signaux[0] = SignalGBF(liste_tmin_tmax = liste_tmin_tmax2, Te = Te)
     
     liste_signaux[0].configurer_voie("SA1", repetition = True)
     liste_signaux[1].configurer_voie("SA2", repetition = True)
