@@ -12,9 +12,9 @@ except:
     import acquisition.emulateur_sysam_sp5 as pycan
 
 from signaux.signal_base import SignalBase
-from signaux.signal_gbf import GBF
-from signaux.signal_fourier import Fourier
-from signaux.signal_sysam import Sysam
+from signaux.signal_gbf import SignalGBF
+from signaux.signal_fourier import SignalFourier
+from signaux.signal_sysam import SignalSysam
 
 import base.temps_base
 import base.voie_base
@@ -116,12 +116,12 @@ if __name__ == "__main__":
     # def faire_une_mesure(f, Ue, tau, n_periodes):
     #     T = 1/f
     #     Te = max(T/100, 2e-7)
-    #     s = GBF("cosinus", F = f, liste_tmin_tmax = [0, T], Te = Te)    
+    #     s = SignalGBF("cosinus", F = f, liste_tmin_tmax = [0, T], Te = Te)    
     #     s.configurer_voie("SA1", repetition = True)
     #     print("se")
-    #     se = Sysam("EA0", liste_tmin_tmax = [tau, tau + n_periodes*T], Te = Te)
+    #     se = SignalSysam("EA0", liste_tmin_tmax = [tau, tau + n_periodes*T], Te = Te)
     #     print("ss")
-    #     ss = Sysam("EA1", liste_tmin_tmax = [tau, tau + n_periodes*T], Te = Te)
+    #     ss = SignalSysam("EA1", liste_tmin_tmax = [tau, tau + n_periodes*T], Te = Te)
     #     se.configurer_trigger(0)
     #     sysam = SysamSP5([s, se, ss])
 
@@ -129,7 +129,7 @@ if __name__ == "__main__":
     #     Vpps = ss.mesurer_Vpp()
     #     G = Vpps / Vppe
     #     phi = ss.mesurer_dephasage_par_rapport_a(se)
-    #     Sysam.tracer_signaux([se, ss])
+    #     SignalSysam.tracer_signaux([se, ss])
     #     return G, phi
 
     # def tracer_bode(liste_fmin_fmax, n_points, Ue, tau, n_periodes):
@@ -152,29 +152,29 @@ if __name__ == "__main__":
     # # tracer_bode([50, 80000], 10, 9, 1e-1, 30)
     # Ts2 = 0.01
     # F = 1/Ts2/2
-    # ss = GBF("carre", F = F, liste_tmin_tmax = [0, 1/F], Te = 1e-4)
+    # ss = SignalGBF("carre", F = F, liste_tmin_tmax = [0, 1/F], Te = 1e-4)
     # ss.configurer_voie("SA1", repetition = False)
-    # sss = Sysam("EA0", liste_tmin_tmax = [0.001, 3*Ts2], Te = 1e-4)
-    # ssss = Sysam("EA1", liste_tmin_tmax = [0.001, 3*Ts2], Te = 1e-4)
+    # sss = SignalSysam("EA0", liste_tmin_tmax = [0.001, 3*Ts2], Te = 1e-4)
+    # ssss = SignalSysam("EA1", liste_tmin_tmax = [0.001, 3*Ts2], Te = 1e-4)
     # demarrer_sysam([ss, sss, ssss])
     
     # print(ss.base_de_temps.Nsysam)
     # print(sss.base_de_temps.Nsysam)
     # print(ssss.base_de_temps.Nsysam)
 
-    # Sysam.tracer_signaux([sss,ssss], superposition = False)
+    # SignalSysam.tracer_signaux([sss,ssss], superposition = False)
     T1 = 1e-3
-    sortie1 = GBF(F = 1/T1, liste_tmin_tmax = [0, T1], Te = 2e-7)
+    sortie1 = SignalGBF(F = 1/T1, liste_tmin_tmax = [0, T1], Te = 2e-7)
     sortie1.configurer_voie("SA1", repetition = True)
 
-    entree1 = Sysam("DIFF3", liste_tmin_tmax = [0, 5*T1], Te = 1e-7)
+    entree1 = SignalSysam("DIFF3", liste_tmin_tmax = [0, 5*T1], Te = 1e-7)
     entree1.configurer_trigger(0)
 
     T2 = 2.5e-3
-    sortie2 = GBF(F = 1/T2, liste_tmin_tmax = [0, T2], Te = 7e-7)
+    sortie2 = SignalGBF(F = 1/T2, liste_tmin_tmax = [0, T2], Te = 7e-7)
     sortie2.configurer_voie("SA2", repetition = True)
 
-    entree2 = Sysam("EA2", liste_tmin_tmax = [0, 5*T1], Te = 1e-7)
+    entree2 = SignalSysam("EA2", liste_tmin_tmax = [0, 5*T1], Te = 1e-7)
     
     demarrer_sysam(entree1, sortie1, entree2, sortie2, True)
-    GBF.tracer_signaux(sortie2, entree1, entree2, titre = "zoo")
\ No newline at end of file
+    SignalGBF.tracer_signaux(sortie2, entree1, entree2, titre = "zoo")
\ No newline at end of file
